==> libjboss-microcontainer-java_2.0.3.GA.orig.tar.gz: libjboss-microcontainer-java-2.0.3.GA.orig/kernel/src/test/java/org/jboss/test/kernel/deployment/support/container/TestSessionBean.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2006, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.test.kernel.deployment.support.container;

import org.jboss.beans.metadata.api.annotations.Inject;
import org.jboss.dependency.spi.Controller;
import org.jboss.kernel.plugins.bootstrap.basic.KernelConstants;

/**
 * @author <a href="mailto:ales.justin@jboss.com">Ales Justin</a>
 */
public class TestSessionBean
{
   @EJB
   private OtherSessionBean other;

   @Inject(bean = KernelConstants.KERNEL_CONTROLLER_NAME)
   private Controller controller;

   public void validate()
   {
      if (other == null)
         throw new RuntimeException("Other is null");
      if (controller == null)
         throw new RuntimeException("Controller is null");
   }
}

==> libjboss-microcontainer-java_2.0.10.GA.orig.tar.gz: libjboss-microcontainer-java-2.0.10.GA.orig/kernel/src/test/java/org/jboss/test/kernel/deployment/support/container/TestSessionBean.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2006, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.test.kernel.deployment.support.container;

import org.jboss.beans.metadata.api.annotations.Inject;
import org.jboss.dependency.spi.Controller;
import org.jboss.kernel.plugins.bootstrap.basic.KernelConstants;

/**
 * @author <a href="mailto:ales.justin@jboss.com">Ales Justin</a>
 */
public class TestSessionBean
{
   @EJB
   private OtherSessionBean other;

   @Inject(bean = KernelConstants.KERNEL_CONTROLLER_NAME)
   private Controller controller;
   
   // Will be injected by method level @Inject
   private Controller oneMoreController;

   public void validate()
   {
      if (other == null)
         throw new RuntimeException("Other is null");
      if (controller == null)
         throw new RuntimeException("Controller is null");
      if (oneMoreController == null)
    	  throw new RuntimeException("Other controller is null - Method level @Inject did not work");
   }
   
   @Inject (bean = KernelConstants.KERNEL_CONTROLLER_NAME)
   public void setOneMoreController(Controller cont)
   {
	   this.oneMoreController = cont;
   }
}
